"""
Core modules for German phoneme validation.

This is an internal package. For public API, import from the root package:
    from german_phoneme_validator import validate_phoneme
"""

from .models import HybridCNNMLP_V4_3

__all__ = [
    'HybridCNNMLP_V4_3',
]
